@@ -808,7 +808,7 @@ def PROMPT_FIELDS():
         prompt_end="#" if xt.is_superuser() else "$",
         hostname=socket.gethostname().split(".", 1)[0],
         cwd=_dynamically_collapsed_pwd,
-        cwd_dir=lambda: os.path.dirname(_replace_home_cwd()),
+        cwd_dir=lambda: os.path.join(os.path.dirname(_replace_home_cwd()), ""),
         cwd_base=lambda: os.path.basename(_replace_home_cwd()),
         short_cwd=_collapsed_pwd,
         curr_branch=current_branch,
